@@ -1,17 +1,19 @@
-from typing import Optional
-from turing.generated.models import Project
+from turing.ensembler import Ensembler, EnsemblerType, PyFuncEnsembler
+from turing.project import Project
 from turing.session import TuringSession
-from turing.version import VERSION
+from turing.version import VERSION as __version__
 
-
-active_session: TuringSession = TuringSession(host="http://localhost:8080", use_google_oauth=False)
+active_session: TuringSession = TuringSession(
+    host="http://localhost:8080",
+    use_google_oauth=False
+)
 
 
 def set_url(url: str, use_google_oauth: bool = True):
     """
-    Set Turing URL
+    Set Turing API URL
 
-    :param url: Turing URL
+    :param url: Turing API URL
     :param use_google_oauth: whether use google auth or not
     """
 
@@ -28,13 +30,4 @@ def set_project(project_name: str):
     active_session.set_project(project_name)
 
 
-def active_project() -> Optional[Project]:
-    """
-    Get current active project
-
-    :return: active project
-    """
-    return active_session.active_project
-
-
-__version__ = VERSION
+__all__ = ["set_url", "set_project", "active_session"]
